@@ -138,7 +138,10 @@ clearlooks_draw_top_left_highlight (cairo_t *cr,
 	cairo_stroke          (cr);
 }
 
+#ifdef DEVELOPMENT
 #warning seems to be very slow in scrollbar_stepper
+#endif
+
 static void
 clearlooks_draw_highlight_and_shade (cairo_t *cr,
                                      const ShadowParameters *params,
@@ -243,8 +246,8 @@ clearlooks_draw_button (cairo_t *cr,
 	const CairoColor *border_disabled = &colors->shade[4];
 	
 	/* Set colors and stuff */
-//	if (params->focus && !params->active)
-//		border_normal = &colors->spot[2];
+	/* if (params->focus && !params->active)
+		border_normal = &colors->spot[2]; */
 	
 	cairo_translate (cr, x, y);
 	cairo_set_line_width (cr, 1.0);
@@ -401,7 +404,7 @@ clearlooks_draw_entry (cairo_t *cr,
 	if (params->focus)
 	{
 		cairo_rectangle (cr, 2, 2, width-5, height-5);
-	//	clearlooks_rounded_rectangle (cr, 2, 2, width-5, height-5, RADIUS-1, params->corners);
+		/* clearlooks_rounded_rectangle (cr, 2, 2, width-5, height-5, RADIUS-1, params->corners); */
 		cairo_set_source_rgb (cr, colors->spot[0].r, colors->spot[0].g, colors->spot[0].b);
 		cairo_stroke (cr);
 	}
@@ -584,7 +587,7 @@ clearlooks_draw_slider (cairo_t *cr,
 	cairo_set_line_width (cr, 1.0);	
 	cairo_translate      (cr, x, y);
 
-	// fill the widget
+	/* fill the widget */
 	cairo_rectangle (cr, 0.5, 0.5, width-2, height-2);
 
 	/* Fake light */
@@ -1041,8 +1044,8 @@ clearlooks_draw_frame            (cairo_t *cr,
 {
 	const float RADIUS = 3.0;
 	CairoColor *border = frame->border;
-	ClearlooksRectangle bevel_clip;
-	ClearlooksRectangle frame_clip;
+	ClearlooksRectangle bevel_clip = {0, 0, 0, 0};
+	ClearlooksRectangle frame_clip = {0, 0, 0, 0};
 	
 	if (frame->shadow == CL_SHADOW_NONE)
 		return;
@@ -1354,13 +1357,18 @@ clearlooks_draw_list_view_header (cairo_t *cr,
 	cairo_pattern_destroy (pattern);
 	
 	/* Draw resize grip */
-	if (header->order != CL_ORDER_LAST || header->resizable)
+	if ((widget->ltr && header->order != CL_ORDER_LAST) ||
+	    (!widget->ltr && header->order != CL_ORDER_FIRST) || header->resizable)
 	{
 		SeparatorParameters separator;
 		separator.horizontal = FALSE;
 		
-		clearlooks_draw_separator (cr, colors, widget, &separator,
-		                           width-1.5, 4.0, 2, height-8.0);
+		if (widget->ltr)
+			clearlooks_draw_separator (cr, colors, widget, &separator,
+			                           width-1.5, 4.0, 2, height-8.0);
+		else
+			clearlooks_draw_separator (cr, colors, widget, &separator,
+			                           1.5, 4.0, 2, height-8.0);
 	}
 }
 
@@ -1436,7 +1444,7 @@ clearlooks_draw_scrollbar_trough (cairo_t *cr,
 	ge_shade_color (bg, 0.95, &bg_shade);
 	
 	cairo_set_line_width (cr, 1);
-	//cairo_translate (cr, x, y);
+	/* cairo_translate (cr, x, y); */
 	
 	if (scrollbar->horizontal)
 	{
@@ -1480,8 +1488,7 @@ clearlooks_draw_scrollbar_stepper (cairo_t *cr,
 {
 	ClearlooksCorners corners = CL_CORNER_NONE;
 	CairoColor *border = (CairoColor*)&colors->shade[6];
-	CairoColor *bg     = (CairoColor*)&colors->bg[widget->state_type];
-	CairoColor  bg_shade1, bg_shade2;
+	CairoColor  s1, s2, s3, s4;
 	cairo_pattern_t *pattern;
 	ShadowParameters shadow;
 	
@@ -1500,9 +1507,6 @@ clearlooks_draw_scrollbar_stepper (cairo_t *cr,
 			corners = CL_CORNER_BOTTOMLEFT | CL_CORNER_BOTTOMRIGHT;
 	}
 	
-	ge_shade_color (bg, 0.95, &bg_shade1);
-	ge_shade_color (bg, 1.02, &bg_shade2);
-	
 	cairo_translate (cr, x, y);
 	cairo_set_line_width (cr, 1);
 	
@@ -1512,10 +1516,16 @@ clearlooks_draw_scrollbar_stepper (cairo_t *cr,
 		pattern = cairo_pattern_create_linear (0, 0, 0, height);
 	else
 		pattern = cairo_pattern_create_linear (0, 0, width, 0);
-		
-	cairo_pattern_add_color_stop_rgb (pattern, 0,   bg_shade2.r, bg_shade2.g, bg_shade2.b);
-	cairo_pattern_add_color_stop_rgb (pattern, 0.5, bg_shade2.r, bg_shade2.g, bg_shade2.b);
-	cairo_pattern_add_color_stop_rgb (pattern, 1,   bg_shade1.r, bg_shade1.g, bg_shade1.b);
+				
+	s3 = colors->bg[widget->state_type];
+	ge_shade_color(&s3, 1.15, &s1);
+	ge_shade_color(&s3, 1.03, &s2); 
+	ge_shade_color(&s3, 0.92,  &s4); 
+	
+	cairo_pattern_add_color_stop_rgb(pattern, 0,    s1.r, s1.g, s1.b);
+	cairo_pattern_add_color_stop_rgb(pattern, 0.3, s2.r, s2.g, s2.b);
+	cairo_pattern_add_color_stop_rgb(pattern, 0.7, s3.r, s3.g, s3.b);
+	cairo_pattern_add_color_stop_rgb(pattern, 1.0,  s4.r, s4.g, s4.b);
 	cairo_set_source (cr, pattern);
 	cairo_fill (cr);
 	cairo_pattern_destroy (pattern);
@@ -1560,6 +1570,19 @@ clearlooks_draw_scrollbar_slider (cairo_t *cr,
 		else
 			height += 1;
 	}
+	
+	if (scrollbar->horizontal)
+	{
+		cairo_translate (cr, x, y);	
+	}
+	else
+	{
+		int tmp = height;
+		clearlooks_rotate_mirror_translate (cr, M_PI/2, x, y, FALSE, FALSE);
+		height = width;
+		width = tmp;
+	}
+	
 
 	if (scrollbar->has_color)
 	{
@@ -1568,19 +1591,7 @@ clearlooks_draw_scrollbar_slider (cairo_t *cr,
 		CairoColor  hilight;
 		CairoColor  shade1, shade2, shade3;
 		cairo_pattern_t *pattern;
-			
-		if (scrollbar->horizontal)
-		{
-			cairo_translate (cr, x, y);	
-		}
-		else
-		{
-			int tmp = height;
-			clearlooks_rotate_mirror_translate (cr, M_PI/2, x, y, FALSE, FALSE);
-			height = width;
-			width = tmp;
-		}
-	
+				
 		if (widget->prelight)
 			ge_shade_color (&fill, 1.1, &fill);
 			
@@ -1611,10 +1622,53 @@ clearlooks_draw_scrollbar_slider (cairo_t *cr,
 	}
 	else
 	{
-		ScrollBarStepperParameters stepper;
-		stepper.stepper = CL_STEPPER_UNKNOWN;
+		CairoColor *border  = (CairoColor*)&colors->shade[6];
+		CairoColor s1, s2, s3, s4;		
+		cairo_pattern_t *pattern;
+		int bar_x, i;
 		
-		clearlooks_draw_scrollbar_stepper (cr, colors, widget, scrollbar, &stepper, x, y, width, height);
+		CairoColor *dark  = (CairoColor*)&colors->shade[4];
+		CairoColor *light = (CairoColor*)&colors->shade[0];		
+		
+		s3 = colors->bg[widget->state_type];
+		ge_shade_color(&s3, 1.15, &s1);
+		ge_shade_color(&s3, 1.03, &s2); 
+		ge_shade_color(&s3, 0.92,  &s4); 
+	
+		pattern = cairo_pattern_create_linear(1, 1, 1, height-1);
+		cairo_pattern_add_color_stop_rgb(pattern, 0,    s1.r, s1.g, s1.b);
+		cairo_pattern_add_color_stop_rgb(pattern, 0.3, s2.r, s2.g, s2.b);
+		cairo_pattern_add_color_stop_rgb(pattern, 0.7, s3.r, s3.g, s3.b);
+		cairo_pattern_add_color_stop_rgb(pattern, 1.0,  s4.r, s4.g, s4.b);
+
+		cairo_rectangle (cr, 1, 1, width-2, height-2);
+		cairo_set_source(cr, pattern);
+		cairo_fill(cr);
+		cairo_pattern_destroy(pattern);
+		
+		cairo_rectangle (cr, 0.5, 0.5, width-1, height-1);
+		cairo_set_source_rgb (cr, border->r, border->g, border->b);
+		cairo_stroke (cr);
+		
+		/* draw handles */
+		cairo_set_line_width (cr, 1);
+		
+		bar_x = width/2 - 4;
+		cairo_translate(cr, 0.5, 0.5);
+		for (i=0; i<3; i++)
+		{
+			cairo_move_to (cr, bar_x, 4);
+			cairo_line_to (cr, bar_x, height-5);
+			cairo_set_source_rgb (cr, dark->r, dark->g, dark->b);
+			cairo_stroke (cr);
+			
+			cairo_move_to (cr, bar_x+1, 4);
+			cairo_line_to (cr, bar_x+1, height-5);
+			cairo_set_source_rgb (cr, light->r, light->g, light->b);
+			cairo_stroke (cr);
+			
+			bar_x += 3;
+		}
 	}
 	
 }
@@ -1840,24 +1894,23 @@ clearlooks_draw_resize_grip (cairo_t *cr,
                              const ResizeGripParameters      *grip,
                              int x, int y, int width, int height)
 {
- 	CairoColor *dark = (CairoColor*)&colors->shade[4];
 	int lx, ly;
  
 	cairo_set_line_width (cr, 1);
-
-	for (ly=0; ly<3; ly++) // vertically, three rows of dots
+	
+	for (ly=0; ly<4; ly++) /* vertically, four rows of dots */
 	{
-		for (lx=0; lx<=ly; lx++) // horizontally
+		for (lx=0; lx<=ly; lx++) /* horizontally */
 		{
-			int ny = (2-ly) * 5;
-			int nx = lx * 4;
+			int ny = (3.5-ly) * 3;
+			int nx = lx * 3;
 
-			cairo_set_source_rgb (cr, dark->r, dark->g, dark->b);
-			cairo_arc (cr, x+width-nx-1, y+height-ny-1, 1.3, 0, M_PI*2);
+			cairo_set_source_rgba (cr, 1, 1, 1, 1.2);
+			cairo_rectangle (cr, x+width-nx-1, y+height-ny-1, 2, 2);
 			cairo_fill (cr);
 
-			cairo_set_source_rgba (cr, 1, 1, 1, 0.5);
-			cairo_arc (cr, x+width-nx, y+height-ny, 1.3, 0, M_PI*2);
+			cairo_set_source_rgba (cr, 0, 0, 0, 0.4);
+			cairo_rectangle (cr, x+width-nx-1, y+height-ny-1, 1, 1);
 			cairo_fill (cr);
 		}
 	}
