@@ -113,8 +113,6 @@ do_hc_draw_arrow (cairo_t *canvas,
                gint width, 
                gint height)
 {
-	gint steps, extra;
-	gint start, increment;
 	gint aw = width, ah = height;
  	GdkPoint points[3];
 
@@ -336,7 +334,7 @@ hc_gtk2_engine_hack_menu_shell_motion(GtkWidget *widget,
                       GdkEventMotion *event, 
                       gpointer user_data)
 {
-  if (IS_MENU_SHELL(widget))
+  if (GE_IS_MENU_SHELL(widget))
     {
       gint pointer_x, pointer_y;
       GdkModifierType pointer_mask;
@@ -344,13 +342,13 @@ hc_gtk2_engine_hack_menu_shell_motion(GtkWidget *widget,
      
       gdk_window_get_pointer(widget->window, &pointer_x, &pointer_y, &pointer_mask);
 	    
-      if (IS_CONTAINER(widget))
+      if (GE_IS_CONTAINER(widget))
         {
           children = gtk_container_get_children(GTK_CONTAINER(widget));
               
           for (child = g_list_first(children); child; child = g_list_next(child))
             {
-	      if ((child->data) && IS_WIDGET(child->data) && 
+	      if ((child->data) && GE_IS_WIDGET(child->data) && 
                   (GTK_WIDGET_STATE(GTK_WIDGET(child->data)) != GTK_STATE_INSENSITIVE))
 	        {
 	          if ((pointer_x >= GTK_WIDGET(child->data)->allocation.x) && 
@@ -388,20 +386,20 @@ hc_gtk2_engine_hack_menu_shell_leave(GtkWidget *widget,
                       GdkEventCrossing *event,
                       gpointer user_data)
 {
-  if (IS_MENU_SHELL(widget))
+  if (GE_IS_MENU_SHELL(widget))
     {
       GList *children = NULL, *child = NULL;
  
-      if (IS_CONTAINER(widget))
+      if (GE_IS_CONTAINER(widget))
         {
           children = gtk_container_get_children(GTK_CONTAINER(widget));
               
           for (child = g_list_first(children); child; child = g_list_next(child))
             {
-	      if ((child->data) && IS_MENU_ITEM(child->data) && 
+	      if ((child->data) && GE_IS_MENU_ITEM(child->data) && 
                   (GTK_WIDGET_STATE(GTK_WIDGET(child->data)) != GTK_STATE_INSENSITIVE))
 	        {
-                  if ((!GTK_IS_MENU(GTK_MENU_ITEM(child->data)->submenu)) || 
+                  if ((!GE_IS_MENU(GTK_MENU_ITEM(child->data)->submenu)) || 
                       (!(GTK_WIDGET_REALIZED(GTK_MENU_ITEM(child->data)->submenu) && 
                          GTK_WIDGET_VISIBLE(GTK_MENU_ITEM(child->data)->submenu) &&
                          GTK_WIDGET_REALIZED(GTK_MENU(GTK_MENU_ITEM(child->data)->submenu)->toplevel) &&
@@ -429,7 +427,7 @@ hc_gtk2_engine_hack_menu_shell_leave(GtkWidget *widget,
 void
 hc_gtk2_engine_hack_menu_shell_setup_signals(GtkWidget *widget)
 {
-  if (IS_MENU_BAR(widget))
+  if (GE_IS_MENU_BAR(widget))
     {
       gint id = 0;
  
@@ -469,7 +467,7 @@ hc_gtk2_engine_hack_menu_shell_setup_signals(GtkWidget *widget)
 void
 hc_gtk2_engine_hack_menu_shell_cleanup_signals(GtkWidget *widget)
 {
-  if (IS_MENU_BAR(widget))
+  if (GE_IS_MENU_BAR(widget))
     {
       gint id = 0;
  
