@@ -50,10 +50,10 @@ thinice_tab(GtkStyle * style,
             gint height,
 	    gint orientation);
 
-static GtkStyleClass *parent_class = NULL;
+static GtkStyleClass *thinice_parent_style_class = NULL;
 
 static void
-draw_hline(GtkStyle * style,
+thinice_style_draw_hline(GtkStyle * style,
            GdkWindow * window,
            GtkStateType state_type,
            GdkRectangle * area,
@@ -63,18 +63,18 @@ draw_hline(GtkStyle * style,
            gint x2,
            gint y)
 {
-	ThiniceStyle *thinice_style = THINICE_STYLE (style);
+	cairo_t *cr;
 	
 	CHECK_ARGS
 
-	cairo_t *cr = ge_gdk_drawable_to_cairo (window, area);
+	cr = ge_gdk_drawable_to_cairo (window, area);
 	
 	thinice_draw_separator(cr, TRUE, x1, y, x2-x1, 2);
 	cairo_destroy (cr);
 }
 
 static void
-draw_vline(GtkStyle * style,
+thinice_style_draw_vline(GtkStyle * style,
            GdkWindow * window,
            GtkStateType state_type,
            GdkRectangle * area,
@@ -84,14 +84,14 @@ draw_vline(GtkStyle * style,
            gint y2,
            gint x)
 {
-	ThiniceStyle *thinice_style = THINICE_STYLE (style);
+	cairo_t *cr;
 
 	CHECK_ARGS
 
 	if (ge_is_combo_box(widget, FALSE) && (!ge_is_combo_box_entry(widget)))
 		return;
 
-	cairo_t *cr = ge_gdk_drawable_to_cairo (window, area);
+	cr = ge_gdk_drawable_to_cairo (window, area);
 	
 	thinice_draw_separator(cr, FALSE, x, y1, 2, y2-y1);
 
@@ -99,7 +99,7 @@ draw_vline(GtkStyle * style,
 }
 
 static void
-draw_shadow(GtkStyle     *style,
+thinice_style_draw_shadow(GtkStyle     *style,
 	    GdkWindow    *window,
 	    GtkStateType  state_type,
 	    GtkShadowType shadow_type,
@@ -115,6 +115,7 @@ draw_shadow(GtkStyle     *style,
 
   CairoColor *color1 = NULL;
   CairoColor *color2 = NULL;
+  cairo_t *cr;
 
   CHECK_ARGS
 
@@ -141,7 +142,7 @@ draw_shadow(GtkStyle     *style,
       break;
     }
 
-  cairo_t *cr = ge_gdk_drawable_to_cairo (window, area);
+  cr = ge_gdk_drawable_to_cairo (window, area);
   
   switch (shadow_type)
     {
@@ -169,7 +170,7 @@ draw_shadow(GtkStyle     *style,
 }
 
 static void
-draw_polygon(GtkStyle * style,
+thinice_style_draw_polygon(GtkStyle * style,
              GdkWindow * window,
              GtkStateType state_type,
              GtkShadowType shadow_type,
@@ -196,6 +197,7 @@ draw_polygon(GtkStyle * style,
   CairoColor *color2 = NULL;
   CairoColor *color3 = NULL;
   CairoColor *color4 = NULL;
+  cairo_t *cr;
 
   gdouble             angle;
   gint                xadjust;
@@ -235,7 +237,7 @@ draw_polygon(GtkStyle * style,
       return;
     }
 
-  cairo_t *cr = ge_gdk_drawable_to_cairo (window, area);
+  cr = ge_gdk_drawable_to_cairo (window, area);
 
   if (fill)
     ge_cairo_polygon(cr, &thinice_style->color_cube.bg[state_type], points, npoints);
@@ -301,7 +303,7 @@ draw_polygon(GtkStyle * style,
 }
 
 static void
-draw_arrow(GtkStyle * style,
+thinice_style_draw_arrow(GtkStyle * style,
            GdkWindow * window,
            GtkStateType state_type,
            GtkShadowType shadow_type,
@@ -315,7 +317,7 @@ draw_arrow(GtkStyle * style,
 
 	CairoColor *color1, *color2, *color3=NULL,*color4=NULL;
 	gint half_width, half_height;
-        gint ax, ay, aw, ah;
+	cairo_t *cr;
 
 	CHECK_ARGS
 
@@ -324,6 +326,9 @@ draw_arrow(GtkStyle * style,
 
 	SANITIZE_SIZE
 
+	half_width = width / 2;
+	half_height = height / 2;
+
 	switch (shadow_type)
 	{
 		case GTK_SHADOW_IN:
@@ -359,7 +364,7 @@ draw_arrow(GtkStyle * style,
 			return;
 	}
 
-	cairo_t *cr = ge_gdk_drawable_to_cairo (window, area);
+	cr = ge_gdk_drawable_to_cairo (window, area);
 
 	if (CHECK_DETAIL (detail, "vscrollbar") || CHECK_DETAIL (detail, "hscrollbar"))
 	{
@@ -403,7 +408,7 @@ draw_arrow(GtkStyle * style,
 }
 
 static void
-draw_diamond(GtkStyle * style,
+thinice_style_draw_diamond(GtkStyle * style,
              GdkWindow * window,
              GtkStateType state_type,
              GtkShadowType shadow_type,
@@ -418,6 +423,7 @@ draw_diamond(GtkStyle * style,
 	ThiniceStyle *thinice_style = THINICE_STYLE (style);
   gint                half_width;
   gint                half_height;
+  cairo_t *cr;
 
   CHECK_ARGS
 
@@ -426,7 +432,7 @@ draw_diamond(GtkStyle * style,
   half_width = width / 2;
   half_height = height / 2;
 
-  cairo_t *cr = ge_gdk_drawable_to_cairo (window, area);
+  cr = ge_gdk_drawable_to_cairo (window, area);
 
   switch (shadow_type)
     {
@@ -516,7 +522,7 @@ draw_diamond(GtkStyle * style,
 }
 
 static void
-draw_box(GtkStyle * style,
+thinice_style_draw_box(GtkStyle * style,
          GdkWindow * window,
          GtkStateType state_type,
          GtkShadowType shadow_type,
@@ -529,200 +535,155 @@ draw_box(GtkStyle * style,
          gint height)
 {
 	ThiniceStyle *thinice_style = THINICE_STYLE (style);
+	cairo_t *canvas;
+	gboolean draw_border = TRUE;
 
-  CairoColor *light, *dark;
+	/***********************************************/
+	/* GTK Sanity Checks                           */
+	/***********************************************/
+	CHECK_ARGS
+	SANITIZE_SIZE 
 
-  CHECK_ARGS
 
-  SANITIZE_SIZE
+	/***********************************************/
+	/* GTK Special Cases - Ignored Widgets         */
+	/***********************************************/
+	if ((CHECK_DETAIL(detail, "optionmenutab")) ||
+		(CHECK_DETAIL (detail, "slider")) ||
+		(CHECK_DETAIL (detail, "buttondefault")) ||
+		(CHECK_DETAIL (detail, "bar") && 
+			((height < 1) && (width < 1))))
+	{
+		return;
+	}
 
-  if (CHECK_DETAIL(detail, "optionmenutab"))
-	return;
 
-  light = &thinice_style->color_cube.light[state_type];
-  dark = &thinice_style->color_cube.dark[state_type];
+	/***********************************************/
+	/* GTK Special Cases - adjust Size/Offset      */
+	/***********************************************/
+	if ((CHECK_DETAIL (detail, "bar")))
+	{
+		x += 1;
+		y += 1;
+		width -= 2;
+		height -= 2;
 
-  cairo_t *cr = ge_gdk_drawable_to_cairo (window, area);
-
- if (CHECK_DETAIL (detail, "trough"))
-    {
-           ge_cairo_set_color(cr, &thinice_style->color_cube.bg[state_type]);
-
-           cairo_rectangle(cr, x, y, width, height);
-
-           cairo_fill(cr);
-
-      draw_shadow(style, window, state_type, shadow_type, area, widget,
-                       detail, x, y, width, height);
+		draw_border=FALSE;
     }
-  else if (CHECK_DETAIL (detail, "slider"))
-    {
-    }
-  else if (CHECK_DETAIL (detail, "buttondefault"))
-    {
-      /* I don't want no background on default buttons..
-         Let's add that cute triangle (see below) instead... */
-    }
-  else if (CHECK_DETAIL (detail, "button"))
-    {
-      if ((!style->bg_pixmap[state_type]) || GDK_IS_PIXMAP (window))
-        {
-           ge_cairo_set_color(cr, &thinice_style->color_cube.bg[state_type]);
+	else if (CHECK_DETAIL (detail, "handlebox_bin"))
+	{
+		draw_border=FALSE;
+	}
 
-           cairo_rectangle(cr, x+1, y+1, width-2, height-2);
 
-           cairo_fill(cr);
+	/***********************************************/
+	/* Fill Box                                    */
+	/***********************************************/
+	if ((!style->bg_pixmap[state_type]) || GDK_IS_PIXMAP(window))
+	{
+		canvas = ge_gdk_drawable_to_cairo (window, area);
 
-        }
-      else
-        {
-          gtk_style_apply_default_background(style, window,
-                                             widget && !GTK_WIDGET_NO_WINDOW(widget),
-                                             state_type, area,
-                                             x, y, width, height);
-        }
-      /* Paint a triangle here instead of in "buttondefault"
-         which is drawn _behind_ the current button */
-      if (GTK_WIDGET_HAS_DEFAULT (widget))
-        {
-          cairo_set_line_width (cr, 1);
+		ge_cairo_set_color(canvas, &thinice_style->color_cube.bg[state_type]);
 
-          ge_cairo_set_color(cr, &thinice_style->color_cube.bg[GTK_STATE_SELECTED]);
-          cairo_move_to(cr, x+2.5, y+2.5);
-          cairo_line_to(cr, x+10.5, y+2.5);
-          cairo_line_to(cr, x+2.5, y+10.5);
-          cairo_line_to(cr, x+2.5, y+2.5);
-	  cairo_fill(cr);
+		cairo_rectangle(canvas, x, y, width, height);
 
-          ge_cairo_set_color(cr, dark);
-	  cairo_move_to(cr, x + 2.5, y + 11);
-	  cairo_line_to(cr, x + 2.5, y + 2.5);
-  	  cairo_line_to(cr, x + 11, y + 2.5);
-	  cairo_stroke(cr);
+		cairo_fill(canvas);
 
-          cairo_set_line_width (cr, 0.5);
-          ge_cairo_set_color(cr, light);
-          cairo_move_to(cr, x+11, y+3);
-          cairo_line_to(cr, x+3, y+11);
-	  cairo_stroke(cr);
-        }
+		cairo_destroy(canvas);
+	}
+	else
+	{
+		gtk_style_apply_default_background(style, window,
+				widget && !GTK_WIDGET_NO_WINDOW(widget),
+				state_type, area,
+				x, y, width, height);
+	}
+	
+	/***********************************************/
+	/* Draw Box Border                             */
+	/***********************************************/
+	if (draw_border)
+	{
+		thinice_style_draw_shadow(style, window, state_type, shadow_type, area, widget,
+						detail, x, y, width, height);
+	}
 
-      draw_shadow(style, window, state_type, shadow_type, area, widget,
-                       detail, x, y, width, height);
-    }
-  else if (CHECK_DETAIL (detail, "bar"))
-    {
-      if ((height > 1) && (width > 1))
-        {
+	/***********************************************/
+	/* Draw Widget Specific Sub-Parts              */
+	/***********************************************/
+	if (CHECK_DETAIL (detail, "button"))
+	{
+		/* Paint a triangle here instead of in "buttondefault"
+			which is drawn _behind_ the current button */
+		if (widget && GE_WIDGET_HAS_DEFAULT (widget))
+		{
+			canvas = ge_gdk_drawable_to_cairo (window, area);
 
-           ge_cairo_set_color(cr, &thinice_style->color_cube.bg[state_type]);
+			ge_cairo_set_color(canvas, &thinice_style->color_cube.bg[GTK_STATE_SELECTED]);
+			cairo_move_to(canvas, x+2.5, y+2.5);
+			cairo_line_to(canvas, x+10.5, y+2.5);
+			cairo_line_to(canvas, x+2.5, y+10.5);
+			cairo_line_to(canvas, x+2.5, y+2.5);
+			cairo_fill(canvas);
 
-           cairo_rectangle(cr, x+1, y+1, width-2, height-2);
+			ge_cairo_set_color(canvas, &thinice_style->color_cube.dark[state_type]);
+			cairo_move_to(canvas, x + 2.5, y + 11);
+			cairo_line_to(canvas, x + 2.5, y + 2.5);
+			cairo_line_to(canvas, x + 11, y + 2.5);
+			cairo_stroke(canvas);
 
-           cairo_fill(cr);
+			cairo_set_line_width (canvas, 0.5);
+			ge_cairo_set_color(canvas, &thinice_style->color_cube.light[state_type]);
+			cairo_move_to(canvas, x+11, y+3);
+			cairo_line_to(canvas, x+3, y+11);
+			cairo_stroke(canvas);
 
-        }
-    }
-  else if (CHECK_DETAIL (detail, "handlebox_bin"))
-    {
-      if ((!style->bg_pixmap[state_type]) || GDK_IS_PIXMAP(window))
-        {
-           ge_cairo_set_color(cr, &thinice_style->color_cube.bg[state_type]);
+			cairo_destroy(canvas);
+		}
+	}
 
-           cairo_rectangle(cr, x, y, width, height);
-
-           cairo_fill(cr);
-
-        }
-      else
-        {
-          gtk_style_apply_default_background(style, window,
-                                             widget && !GTK_WIDGET_NO_WINDOW(widget),
-                                             state_type, area,
-                                             x, y, width, height);
-        }
-    }
-  else if (CHECK_DETAIL (detail, "menubar"))
-    {
-      if ((!style->bg_pixmap[state_type]) || GDK_IS_PIXMAP(window))
-        {
-           ge_cairo_set_color(cr, &thinice_style->color_cube.bg[state_type]);
-
-           cairo_rectangle(cr, x, y, width, height);
-
-           cairo_fill(cr);
-        }
-      else
-        {
-          gtk_style_apply_default_background(style, window,
-                                             widget && !GTK_WIDGET_NO_WINDOW(widget),
-                                             state_type, area,
-                                             x, y, width, height);
-        }
-      draw_shadow(style, window, state_type, shadow_type, area, widget,
-                       detail, x, y, width, height);
-    }
-  else
-    {
-
-      if ((!style->bg_pixmap[state_type]) || GDK_IS_PIXMAP(window))
-        {
-           ge_cairo_set_color(cr, &thinice_style->color_cube.bg[state_type]);
-
-           cairo_rectangle(cr, x, y, width, height);
-
-           cairo_fill(cr);
-        }
-      else
-        {
-          gtk_style_apply_default_background(style, window,
-                                             widget && !GTK_WIDGET_NO_WINDOW(widget),
-                                             state_type, area,
-                                             x, y, width, height);
-        }
-      draw_shadow(style, window, state_type, shadow_type, area, widget,
-                       detail, x, y, width, height);
-    }
-
-  if (CHECK_DETAIL(detail, "optionmenu") ||  (CHECK_DETAIL(detail, "button") && 
-       (ge_is_combo_box(widget, FALSE)) && !(ge_is_combo_box_entry(widget))))
-    {
-      GtkRequisition indicator_size;
-      GtkBorder indicator_spacing;
-      gint vline_x;
+	/* Draw Option Menus and Combo Box "Tab" The Same Way Here */
+	if (CHECK_DETAIL(detail, "optionmenu") ||  (CHECK_DETAIL(detail, "button") && 
+		(ge_is_combo_box(widget, FALSE)) && !(ge_is_combo_box_entry(widget))))
+	{
+		GtkRequisition indicator_size;
+		GtkBorder indicator_spacing;
+		gint vline_x;
  
-      if (state_type != GTK_STATE_INSENSITIVE)
-        state_type = GTK_STATE_NORMAL;
+		if (state_type != GTK_STATE_INSENSITIVE)
+			state_type = GTK_STATE_NORMAL;
  
-      ge_option_menu_get_props (widget, &indicator_size, &indicator_spacing);
+		ge_option_menu_get_props (widget, &indicator_size, &indicator_spacing);
  
-      if ((!widget) || (gtk_widget_get_direction (widget) == GTK_TEXT_DIR_RTL))
-	vline_x = x + indicator_size.width + indicator_spacing.left + indicator_spacing.right;
-      else
-	vline_x = x + width - (indicator_size.width + indicator_spacing.left + 
-                               indicator_spacing.right) - style->xthickness;
+		if ((!widget) || (gtk_widget_get_direction (widget) == GTK_TEXT_DIR_RTL))
+			vline_x = x + indicator_size.width + indicator_spacing.left + indicator_spacing.right;
+		else
+			vline_x = x + width - (indicator_size.width + indicator_spacing.left + 
+						indicator_spacing.right) - style->xthickness;
 
-      thinice_draw_separator(cr, FALSE, vline_x, y + style->ythickness + 1, style->xthickness, height - 2*style->ythickness - 2);
- 
-      if ((widget) && (gtk_widget_get_direction (GTK_WIDGET (widget)) == GTK_TEXT_DIR_RTL))
-         x +=  indicator_spacing.right + style->xthickness;
-      else
-         x += width - indicator_size.width - indicator_spacing.right - style->xthickness;
- 
-      y += ((height - indicator_size.height) / 2) + 1;
- 
-      width = indicator_size.width;
-      height = indicator_size.height;
- 
-      draw_arrow (style, window, state_type, shadow_type, area, NULL, "optionmenu", 
-	                      GTK_ARROW_DOWN, TRUE,  x,  y,  width,  height);
-   }
+		canvas = ge_gdk_drawable_to_cairo (window, area);
 
-  cairo_destroy(cr);
+		thinice_draw_separator(canvas, FALSE, vline_x, y + style->ythickness + 1, style->xthickness, height - 2*style->ythickness - 2);
+
+		cairo_destroy(canvas);
+ 
+		if ((widget) && (gtk_widget_get_direction (GTK_WIDGET (widget)) == GTK_TEXT_DIR_RTL))
+			x +=  indicator_spacing.right + style->xthickness;
+		else
+			x += width - indicator_size.width - indicator_spacing.right - style->xthickness;
+ 
+		y += ((height - indicator_size.height) / 2) + 1;
+ 
+		width = indicator_size.width;
+		height = indicator_size.height;
+ 
+		thinice_style_draw_arrow (style, window, state_type, shadow_type, area, NULL, "optionmenu", 
+						GTK_ARROW_DOWN, TRUE,  x,  y,  width,  height);
+	}
 }
 
 static void
-draw_check(GtkStyle * style,
+thinice_style_draw_check(GtkStyle * style,
            GdkWindow * window,
            GtkStateType state_type,
            GtkShadowType shadow_type,
@@ -737,6 +698,7 @@ draw_check(GtkStyle * style,
 	ThiniceStyle *thinice_style = THINICE_STYLE (style);
 
 	CairoColor              *color1 = NULL;
+	cairo_t *cr;
 
 	CHECK_ARGS
 	SANITIZE_SIZE
@@ -746,7 +708,7 @@ draw_check(GtkStyle * style,
 		color1 = &thinice_style->color_cube.bg[GTK_STATE_ACTIVE];
 	}
 
-	cairo_t *cr = ge_gdk_drawable_to_cairo (window, area);
+	cr = ge_gdk_drawable_to_cairo (window, area);
 
 	if (state_type == GTK_STATE_INSENSITIVE)
 	{
@@ -758,7 +720,7 @@ draw_check(GtkStyle * style,
 	}
 	else
 	{
-		draw_box(style, window, state_type, shadow_type, area, widget,
+		thinice_style_draw_box(style, window, state_type, shadow_type, area, widget,
                 			detail, x, y, width, height);
 		if (color1)
 		{
@@ -776,7 +738,7 @@ draw_check(GtkStyle * style,
 
 /* Thanks to Evan Lawrence */
 static void
-draw_option(GtkStyle * style,
+thinice_style_draw_option(GtkStyle * style,
             GdkWindow * window,
             GtkStateType state_type,
             GtkShadowType shadow_type,
@@ -791,6 +753,11 @@ draw_option(GtkStyle * style,
 	ThiniceStyle *thinice_style = THINICE_STYLE (style);
 
 	CairoColor              *color1 = NULL, *color2 = NULL, *color3 = NULL;
+	cairo_t *cr;
+
+  gint centerX;
+  gint centerY;
+  gint radius;
 
 	CHECK_ARGS
 	SANITIZE_SIZE
@@ -809,12 +776,12 @@ draw_option(GtkStyle * style,
 			color3 = &thinice_style->color_cube.bg[state_type];
     }
 
-	cairo_t *cr = ge_gdk_drawable_to_cairo (window, area);
+	cr = ge_gdk_drawable_to_cairo (window, area);
       cairo_set_line_width (cr, 0.5);
 
-  gint centerX = x + floor(width/2);
-  gint centerY = y + floor(height/2);
-  gint radius = floor(width/2) - 0.5;
+  centerX = x + floor(width/2);
+  centerY = y + floor(height/2);
+  radius = floor(MIN(width, height)/2) - 0.5;
 
   switch (shadow_type)
     {
@@ -850,13 +817,14 @@ draw_option(GtkStyle * style,
 
       cairo_close_path (cr);
 
+      cairo_save(cr);
       cairo_clip (cr);
 
       ge_cairo_set_color(cr, color2);
       cairo_arc(cr, centerX, centerY, radius + 1, 0,  2*M_PI);
       cairo_fill(cr);
 
-      cairo_reset_clip(cr);
+      cairo_restore(cr);
 
       cairo_new_path (cr);
 
@@ -867,13 +835,15 @@ draw_option(GtkStyle * style,
 
       cairo_close_path (cr);
 
+      cairo_save(cr);
+
       cairo_clip (cr);
 
       ge_cairo_set_color(cr, color1); 
       cairo_arc(cr, centerX, centerY, radius + 1, 0,  2*M_PI);
       cairo_fill(cr);
 
-      cairo_reset_clip(cr);
+      cairo_restore(cr);
 
       ge_cairo_set_color(cr, color3);
       cairo_arc(cr, centerX, centerY, radius, 0, 2 * M_PI);
@@ -886,7 +856,7 @@ draw_option(GtkStyle * style,
 }
 
 static void
-draw_shadow_gap(GtkStyle * style,
+thinice_style_draw_shadow_gap(GtkStyle * style,
                 GdkWindow * window,
                 GtkStateType state_type,
                 GtkShadowType shadow_type,
@@ -904,6 +874,7 @@ draw_shadow_gap(GtkStyle * style,
 	ThiniceStyle *thinice_style = THINICE_STYLE (style);
 
 	CairoColor              *color1 = NULL, *color2 = NULL;
+	cairo_t *cr;
 
 	CHECK_ARGS
 	SANITIZE_SIZE
@@ -927,7 +898,7 @@ draw_shadow_gap(GtkStyle * style,
 		color2 = &thinice_style->color_cube.dark[state_type];
 	}
 
-	cairo_t *cr = ge_gdk_drawable_to_cairo (window, area);
+	cr = ge_gdk_drawable_to_cairo (window, area);
 
 	switch (gap_side) {
         case GTK_POS_TOP:
@@ -1027,7 +998,7 @@ draw_shadow_gap(GtkStyle * style,
 
 
 static void
-draw_box_gap(GtkStyle * style,
+thinice_style_draw_box_gap(GtkStyle * style,
              GdkWindow * window,
              GtkStateType state_type,
              GtkShadowType shadow_type,
@@ -1048,14 +1019,14 @@ draw_box_gap(GtkStyle * style,
             widget && !GTK_WIDGET_NO_WINDOW(widget),
             state_type, area,
             x, y, width, height);
-    draw_shadow_gap (style, window, state_type, shadow_type,
+    thinice_style_draw_shadow_gap (style, window, state_type, shadow_type,
             area, widget, detail, x, y, width, height,
             gap_side, gap_x, gap_width);
 }
 
 
 static void
-draw_extension(DRAW_ARGS, GtkPositionType gap_side)
+thinice_style_draw_extension(DRAW_ARGS, GtkPositionType gap_side)
 {
 	switch (gap_side)
 	{
@@ -1069,7 +1040,7 @@ draw_extension(DRAW_ARGS, GtkPositionType gap_side)
 }
 
 static void
-draw_slider(GtkStyle * style,
+thinice_style_draw_slider(GtkStyle * style,
             GdkWindow * window,
             GtkStateType state_type,
             GtkShadowType shadow_type,
@@ -1087,7 +1058,7 @@ draw_slider(GtkStyle * style,
   GdkPoint pointsh[7];
   gint i, rect = FALSE, midlines = MARKS_SLASH;
   gint modx, mody;
-  
+  cairo_t *cr;
 
   CHECK_ARGS
 
@@ -1144,7 +1115,7 @@ draw_slider(GtkStyle * style,
           pointsh[6].x = x;                  pointsh[6].y = y+height-1;
         }
 
-      cairo_t *cr = ge_gdk_drawable_to_cairo (window, area);
+      cr = ge_gdk_drawable_to_cairo (window, area);
 
       if (rect)
         {
@@ -1154,7 +1125,7 @@ draw_slider(GtkStyle * style,
 
            cairo_fill(cr);
 
-           draw_shadow(style, window, state_type, shadow_type, area,
+           thinice_style_draw_shadow(style, window, state_type, shadow_type, area,
                             widget, detail, x, y, width, height);
         }
       else
@@ -1243,7 +1214,7 @@ draw_slider(GtkStyle * style,
 }
 
 static void
-draw_handle(GtkStyle * style,
+thinice_style_draw_handle(GtkStyle * style,
             GdkWindow * window,
             GtkStateType state_type,
             GtkShadowType shadow_type,
@@ -1258,9 +1229,9 @@ draw_handle(GtkStyle * style,
 {
 	ThiniceStyle *thinice_style = THINICE_STYLE (style);
 
+  cairo_t *cr;
   CairoColor              *light=NULL, *dark=NULL;
   GdkRectangle        dest;
-//  ThemeStyleData     *data = NULL;//style->engine_data;
   gint                modx, mody;
 
   CHECK_ARGS
@@ -1271,7 +1242,7 @@ draw_handle(GtkStyle * style,
 #endif
   SANITIZE_SIZE
 
-  cairo_t *cr = ge_gdk_drawable_to_cairo (window, area);
+  cr = ge_gdk_drawable_to_cairo (window, area);
 
   if (CHECK_DETAIL (detail, "paned")) 
     {
@@ -1326,7 +1297,7 @@ draw_handle(GtkStyle * style,
       return;
     }
 
-  draw_box(style, window, state_type, shadow_type, area, widget,
+  thinice_style_draw_box(style, window, state_type, shadow_type, area, widget,
                 detail, x, y, width, height);
 
   ge_cairo_line(cr, &thinice_style->color_cube.light[state_type],
@@ -1396,16 +1367,17 @@ thinice_tab(DRAW_ARGS, gint orientation)
 {
 	ThiniceStyle *thinice_style = THINICE_STYLE (style);
 
+  CairoColor *light, *dark;
+  cairo_t *cr;
+
   CHECK_ARGS
 
   SANITIZE_SIZE
 
-  CairoColor *light, *dark;
-
   light = &thinice_style->color_cube.light[state_type];
   dark = &thinice_style->color_cube.dark[state_type];
 
-  cairo_t *cr = ge_gdk_drawable_to_cairo (window, area);
+  cr = ge_gdk_drawable_to_cairo (window, area);
 
   if ((!style->bg_pixmap[state_type]) || GDK_IS_PIXMAP(window))
     {
@@ -1494,9 +1466,8 @@ static void
 thinice_style_realize (GtkStyle * style)
 {
   ThiniceStyle *thinice_style = THINICE_STYLE (style);
-  int i;
  
-  parent_class->realize (style);
+  thinice_parent_style_class->realize (style);
  
   ge_gtk_style_to_cairo_color_cube (style, &thinice_style->color_cube);
 }
@@ -1506,26 +1477,26 @@ thinice_style_class_init (ThiniceStyleClass *klass)
 {
   GtkStyleClass *style_class = GTK_STYLE_CLASS (klass);
 
-  parent_class = g_type_class_peek_parent (klass);
+  thinice_parent_style_class = g_type_class_peek_parent (klass);
 
   style_class->realize = thinice_style_realize;
 
-  style_class->draw_hline = draw_hline;
-  style_class->draw_vline = draw_vline;
-  style_class->draw_shadow = draw_shadow;
-  style_class->draw_polygon = draw_polygon;
-  style_class->draw_arrow = draw_arrow;
-  style_class->draw_diamond = draw_diamond;
-  style_class->draw_box = draw_box;
-  style_class->draw_tab = draw_box;
+  style_class->draw_hline = thinice_style_draw_hline;
+  style_class->draw_vline = thinice_style_draw_vline;
+  style_class->draw_shadow = thinice_style_draw_shadow;
+  style_class->draw_polygon = thinice_style_draw_polygon;
+  style_class->draw_arrow = thinice_style_draw_arrow;
+  style_class->draw_diamond = thinice_style_draw_diamond;
+  style_class->draw_box = thinice_style_draw_box;
+  style_class->draw_tab = thinice_style_draw_box;
 
-  style_class->draw_check = draw_check;
-  style_class->draw_option = draw_option;
-  style_class->draw_shadow_gap = draw_shadow_gap;
-  style_class->draw_box_gap = draw_box_gap;
-  style_class->draw_extension = draw_extension;
-  style_class->draw_slider = draw_slider;
-  style_class->draw_handle = draw_handle;
+  style_class->draw_check = thinice_style_draw_check;
+  style_class->draw_option = thinice_style_draw_option;
+  style_class->draw_shadow_gap = thinice_style_draw_shadow_gap;
+  style_class->draw_box_gap = thinice_style_draw_box_gap;
+  style_class->draw_extension = thinice_style_draw_extension;
+  style_class->draw_slider = thinice_style_draw_slider;
+  style_class->draw_handle = thinice_style_draw_handle;
 }
 
 
